@@ -13,7 +13,7 @@ use Net::NfDump::Fields;
 
 our @ISA = qw(Exporter);
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 # XXX
 # Items to export into callers namespace by default. Note: do not export
@@ -28,7 +28,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	mac2txt txt2mac
 	mpls2txt txt2mpls
 	flow2txt txt2flow 
-	file_info
+	file_info 
 ) ] );
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
@@ -197,7 +197,7 @@ The architecture is following:
    +------------------------+
    |                        |  The code converts internal nfdump 
    | libnf - glue code (C)  |  structures into perl and back to C.
-   |                        |
+   |                        |  See http://libnf.net for more information.
    +------------------------+
    |                        |  All original nfdump source files. There  
    |   nfdump sources (C)   |  are no changes in these files. All  
@@ -513,11 +513,12 @@ This method has to be applied before any of the C<fetchrow_*> methods is used. A
 # flow query is handled. See section FLOW QUERY how to create flow 
 # queries.
 
-# =cut
+# =cut#
 
 sub query {
 	my ($self, %opts) = @_;
 
+
 	my $o = $self->merge_opts(%opts);
 
 	if (@{$o->{InputFiles}} == 0) {
@@ -562,8 +563,8 @@ sub query {
 
 	# handle, filter, windows start, windows end, ref to filelist 
 	Net::NfDump::libnf_read_files($self->{handle}, $o->{Filter}, 
-					$o->{TimeWindowStart}, $o->{TimeWindowEnd}, 
-					$o->{InputFiles});	
+				$o->{TimeWindowStart}, $o->{TimeWindowEnd}, 
+				$o->{InputFiles});	
 
 	$self->{read_prepared} = 1;
 	$self->{read_started} = time();
@@ -1328,7 +1329,8 @@ another 8 bits for the second one).
 
 =head1 SEE ALSO
 
-http://nfdump.sourceforge.net/
+nfdump project - http://nfdump.sourceforge.net/
+libnf C interface http://libnf.net/
 
 =head1 AUTHOR
 
